@@ -73,7 +73,7 @@ import com.openexchange.api.OXMandatoryFieldException;
 import com.openexchange.api.OXPermissionException;
 import com.openexchange.api2.OXConcurrentModificationException;
 import com.openexchange.api2.OXException;
-import com.openexchange.api2.RdbContactSQLInterface;
+import com.openexchange.api2.RdbContactSQLImpl;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.Types;
@@ -171,20 +171,18 @@ public class ContactRequest {
         }
     }
 
-    public JSONObject actionNew(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXException, AjaxException {
+    public JSONObject actionNew(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXException, AjaxException, OXJSONException {
 
         final Contact contactObj = new Contact();
         final JSONObject jData = DataParser.checkJSONObject(jsonObj, AJAXServlet.PARAMETER_DATA);
 
-        final ContactParser contactparser = new ContactParser(session);
+        final ContactParser contactparser = new ContactParser();
         contactparser.parse(contactObj, jData);
 
         if (!contactObj.containsParentFolderID()) {
             throw new OXMandatoryFieldException("missing folder");
         }
 
-        final Context ctx = session.getContext();
-
         final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newContactInterface(
             contactObj.getParentFolderID(),
             session);
@@ -205,13 +203,11 @@ public class ContactRequest {
         final Contact contactobject = new Contact();
         final JSONObject jData = DataParser.checkJSONObject(jsonObj, AJAXServlet.PARAMETER_DATA);
 
-        final ContactParser contactparser = new ContactParser(session);
+        final ContactParser contactparser = new ContactParser();
         contactparser.parse(contactobject, jData);
 
         contactobject.setObjectID(id);
 
-        final Context ctx = session.getContext();
-
         final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newContactInterface(
             inFolder,
             session);
@@ -249,8 +245,6 @@ public class ContactRequest {
 
             final int[] internalColumns = checkLastModified(columnsToLoad);
 
-            final Context ctx = session.getContext();
-
             final ContactWriter contactWriter = new ContactWriter(timeZone);
 
             final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newContactInterface(
@@ -297,8 +291,6 @@ public class ContactRequest {
         final int objectId = DataParser.checkInt(jData, DataFields.ID);
         final int inFolder = DataParser.checkInt(jData, AJAXServlet.PARAMETER_INFOLDER);
 
-        final Context ctx = session.getContext();
-
         final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newContactInterface(
             inFolder,
             session);
@@ -340,8 +332,6 @@ public class ContactRequest {
 
             final int[] internalColumns = checkLastModified(columnsToLoad);
 
-            final Context ctx = session.getContext();
-
             try {
                 // check if the int array has always the same folder id
                 if (isOneFolder) {
@@ -366,8 +356,6 @@ public class ContactRequest {
                 } else {
                     // costs more performance because every object in the array
                     // is checked
-                    final ContactInterfaceDiscoveryService discoveryService = ServerServiceRegistry.getInstance().getService(
-                        ContactInterfaceDiscoveryService.class);
                     for (int a = 0; a < objectIdAndFolderId.length; a++) {
                         final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
                             ContactInterfaceDiscoveryService.class).newContactInterface(objectIdAndFolderId[a][1], session);
@@ -422,7 +410,7 @@ public class ContactRequest {
 
         try {
             // TODO: Use discovery service?
-            final ContactInterface contactInterface = new RdbContactSQLInterface(session, ctx);
+            final ContactInterface contactInterface = new RdbContactSQLImpl(session, ctx);
             final ContactWriter contactwriter = new ContactWriter(timeZone);
 
             for (int a = 0; a < userIdArray.length; a++) {
@@ -462,8 +450,6 @@ public class ContactRequest {
         try {
             final int[] internalColumns = checkLastModified(columnsToLoad);
 
-            final Context ctx = session.getContext();
-
             final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newContactInterface(
                 folderId,
                 session);
@@ -512,8 +498,6 @@ public class ContactRequest {
         final int id = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_ID);
         final int inFolder = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_INFOLDER);
 
-        final Context ctx = session.getContext();
-
         final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newContactInterface(
             inFolder,
             session);
@@ -537,7 +521,7 @@ public class ContactRequest {
         final Context ctx = session.getContext();
 
         // TODO: Use discovery service?
-        final ContactInterface contactInterface = new RdbContactSQLInterface(session, ctx);
+        final ContactInterface contactInterface = new RdbContactSQLImpl(session, ctx);
 
         timestamp = new Date(0);
 
@@ -610,19 +594,9 @@ public class ContactRequest {
 
         final int[] internalColumns = checkLastModified(columnsToLoad);
 
-        final ContactInterface contactInterface;
-        final int[] folders = searchObj.getFolders();
-        SearchIterator<Contact> it = null;
+        ContactSearchMultiplexer multiplexer = new ContactSearchMultiplexer(ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class));
+        SearchIterator<Contact> it = multiplexer.extendedSearch(session, searchObj, orderBy, orderDir, internalColumns);
         
-        if (null != folders && folders.length >= 1) {
-            ContactSearchMultiplexer multiplexer = new ContactSearchMultiplexer(ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class));
-            it = multiplexer.extendedSearch(session, searchObj, orderBy, orderDir, internalColumns);
-        } else {
-            contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newDefaultContactInterface(
-                session);
-            it = contactInterface.getContactsByExtendedSearch(searchObj, orderBy, orderDir, internalColumns);
-        }
-
         final JSONArray jsonResponseArray = new JSONArray();
         try {
             final ContactWriter contactwriter = new ContactWriter(timeZone);
