@@ -234,6 +234,10 @@ public final class AJPv13RequestHandlerImpl implements AJPv13RequestHandler {
          * Process forward request
          */
         ajpRequest.processRequest(this);
+        /*
+         * Check for possible long-running EAS request
+         */
+        ajpCon.setLongRunning(("/Microsoft-Server-ActiveSync".equals(request.getRequestURI()) && "Ping".equals(request.getParameter("Cmd"))));
         /*
          * Handle the important Content-Length header which controls further processing
          */
