@@ -295,7 +295,7 @@ public class AJPv13TaskWatcher {
             }
             if (task.isProcessing()) {
                 /*
-                 * Task is currently processing
+                 * Task is currently processing and is NOT marked as a long-running task
                  */
                 if (enabled) {
                     processing.incrementAndGet();
@@ -305,7 +305,7 @@ public class AJPv13TaskWatcher {
                     if (enabled) {
                         exceeded.incrementAndGet();
                     }
-                    if (log.isInfoEnabled()) {
+                    if (!task.isLongRunning() && log.isInfoEnabled()) {
                         final Throwable t = new Throwable();
                         t.setStackTrace(task.getStackTrace());
                         log.info(new StringBuilder(128).append("AJP Listener \"").append(task.getThreadName()).append(
@@ -325,7 +325,9 @@ public class AJPv13TaskWatcher {
                          * Send "keep-alive" package
                          */
                         try {
-                            keepAlive(task.getAJPConnection(), task.getSocket().getRemoteSocketAddress().toString());
+                            keepAlive(
+                                task.getAJPConnection(),
+                                log.isInfoEnabled() ? task.getSocket().getRemoteSocketAddress().toString() : null);
                         } catch (final AJPv13Exception e) {
                             log.error("AJP KEEP-ALIVE failed.", e);
                         } catch (final IOException e) {
