@@ -49,6 +49,7 @@
 
 package com.openexchange.event.impl;
 
+import java.util.Dictionary;
 import java.util.Hashtable;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -112,7 +113,7 @@ public class EventClient {
     public void create(final Appointment appointmentObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.INSERT, Types.APPOINTMENT, appointmentObj, null, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/appointment/insert", ht);
@@ -135,7 +136,7 @@ public class EventClient {
     public void modify(final Appointment oldAppointmentObj, final Appointment newAppointmentObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.UPDATE, Types.APPOINTMENT, newAppointmentObj, oldAppointmentObj, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/appointment/update", ht);
@@ -158,7 +159,7 @@ public class EventClient {
     public void accepted(final Appointment oldAppointmentObj, final Appointment newAppointmentObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.CONFIRM_ACCEPTED, Types.APPOINTMENT, newAppointmentObj, oldAppointmentObj, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/appointment/accepted", ht);
@@ -181,7 +182,7 @@ public class EventClient {
     public void declined(final Appointment oldAppointmentObj, final Appointment newAppointmentObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.CONFIRM_DECLINED, Types.APPOINTMENT, newAppointmentObj, oldAppointmentObj, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/appointment/declined", ht);
@@ -204,7 +205,7 @@ public class EventClient {
     public void tentative(final Appointment oldAppointmentObj, final Appointment newAppointmentObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.CONFIRM_TENTATIVE, Types.APPOINTMENT, newAppointmentObj, oldAppointmentObj, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/appointment/tentative", ht);
@@ -227,7 +228,7 @@ public class EventClient {
     public void delete(final Appointment appointmentObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.DELETE, Types.APPOINTMENT, appointmentObj, null, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/appointment/delete", ht);
@@ -240,7 +241,7 @@ public class EventClient {
     public void move(final Appointment appointmentObj, final FolderObject sourceFolder, final FolderObject destinationFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.MOVE, Types.APPOINTMENT, appointmentObj, null, sourceFolder, destinationFolder, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/appointment/move", ht);
@@ -264,7 +265,7 @@ public class EventClient {
     public void create(final Task taskObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.INSERT, Types.TASK, taskObj, null, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/task/insert", ht);
@@ -277,7 +278,7 @@ public class EventClient {
     public void modify(final Task oldTask, final Task newTask, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.UPDATE, Types.TASK, newTask, oldTask, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/task/update", ht);
@@ -300,7 +301,7 @@ public class EventClient {
     public void accept(final Task oldTask, final Task newTask, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.CONFIRM_ACCEPTED, Types.TASK, newTask, oldTask, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/task/accepted", ht);
@@ -323,7 +324,7 @@ public class EventClient {
     public void declined(final Task oldTask, final Task newTask, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.CONFIRM_DECLINED, Types.TASK, newTask, oldTask, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/task/declined", ht);
@@ -346,7 +347,7 @@ public class EventClient {
     public void tentative(final Task oldTask, final Task newTask, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.CONFIRM_TENTATIVE, Types.TASK, newTask, oldTask, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/task/tentative", ht);
@@ -370,7 +371,7 @@ public class EventClient {
     public void delete(final Task taskObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.DELETE, Types.TASK, taskObj, null, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/task/delete", ht);
@@ -383,7 +384,7 @@ public class EventClient {
     public void move(final Task taskObj, final FolderObject sourceFolder, final FolderObject destinationFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.MOVE, Types.TASK, taskObj, null, sourceFolder, destinationFolder, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/task/move", ht);
@@ -406,7 +407,7 @@ public class EventClient {
     public void create(final Contact contactObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.INSERT, Types.CONTACT, contactObj, null, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/contact/insert", ht);
@@ -419,7 +420,7 @@ public class EventClient {
     public void modify(final Contact oldObj, final Contact contactObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.UPDATE, Types.CONTACT, contactObj, oldObj, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/contact/update", ht);
@@ -442,7 +443,7 @@ public class EventClient {
     public void delete(final Contact contactObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.DELETE, Types.CONTACT, contactObj, null, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/contact/delete", ht);
@@ -455,7 +456,7 @@ public class EventClient {
     public void move(final Contact contactObj, final FolderObject folderObj) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.MOVE, Types.CONTACT, contactObj, null, folderObj, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/contact/move", ht);
@@ -478,7 +479,7 @@ public class EventClient {
     public void create(final FolderObject folderObj, final FolderObject parentFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.INSERT, Types.FOLDER, folderObj, null, parentFolder, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/folder/insert", ht);
@@ -491,7 +492,7 @@ public class EventClient {
     public void modify(final FolderObject oldObj, final FolderObject folderObj, final FolderObject parentFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.UPDATE, Types.FOLDER, folderObj, oldObj, parentFolder, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/folder/update", ht);
@@ -519,7 +520,7 @@ public class EventClient {
     public void delete(final FolderObject folderObj, final FolderObject parentFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.DELETE, Types.FOLDER, folderObj, null, parentFolder, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/folder/delete", ht);
@@ -542,7 +543,7 @@ public class EventClient {
     public void create(final DocumentMetadata document, final FolderObject parentFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.INSERT, Types.INFOSTORE, document, null, parentFolder, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/infostore/insert", ht);
@@ -565,7 +566,7 @@ public class EventClient {
     public void modify(final DocumentMetadata oldDocument, final DocumentMetadata document, final FolderObject parentFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.UPDATE, Types.INFOSTORE, document, oldDocument, parentFolder, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/infostore/update", ht);
@@ -589,7 +590,7 @@ public class EventClient {
     public void delete(final DocumentMetadata document, final FolderObject parentFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.DELETE, Types.INFOSTORE, document, null, parentFolder, null, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/infostore/delete", ht);
@@ -602,7 +603,7 @@ public class EventClient {
     public void move(final DocumentMetadata document, final FolderObject sourceFolder, final FolderObject destinationFolder) throws EventException {
         final CommonEvent genericEvent = new CommonEventImpl(userId, contextId, CommonEvent.MOVE, Types.INFOSTORE, document, null, sourceFolder, destinationFolder, session);
 
-        final Hashtable<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
+        final Dictionary<String, CommonEvent> ht = new Hashtable<String, CommonEvent>();
         ht.put(CommonEvent.EVENT_KEY, genericEvent);
 
         final Event event = new Event("com/openexchange/groupware/infostore/move", ht);
