@@ -54,10 +54,8 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
-import java.text.DateFormat;
 import java.util.Date;
 import java.util.List;
-import java.util.Locale;
 import java.util.Set;
 import java.util.TimeZone;
 import com.openexchange.api2.OXException;
@@ -126,6 +124,8 @@ public interface CalendarCollectionService {
     public boolean getWritePermission(final int oid, final int fid, final Session so, final Context ctx) throws OXException;
 
     public boolean checkIfUserIsParticipant(final CalendarDataObject cdao, final UserParticipant up);
+    
+    public void updateDefaultStatus(CalendarDataObject cdao, Context ctx, int uid, int inFolder) throws OXException;
 
     /**
      * Add editing user or shared folder owner to user participants. This ensures
@@ -189,7 +189,7 @@ public interface CalendarCollectionService {
 
     public void triggerModificationEvent(final Session session, final CalendarDataObject oldAppointment, final CalendarDataObject newAppointment) throws OXCalendarException;
 
-    public String getSQLInStringForParticipants(final UserParticipant[] userParticipant);
+    public String getSQLInStringForParticipants(final List<UserParticipant> userParticipant);
 
     public String getSQLInStringForParticipants(final Participant[] participant);
 
