@@ -173,7 +173,7 @@ public final class ConfigTree {
         }
     }
 
-    private static void addElementWithoutOverwriting(Setting actual, Setting subSetting) throws SettingException {
+    private static void addElementWithoutOverwriting(final Setting actual, final Setting subSetting) throws SettingException {
         if(actual.getElement(subSetting.getName()) != null) {
             throw new SettingException(Code.DUPLICATE_PATH, actual.getPath()+"/"+subSetting.getName());
         }
@@ -242,6 +242,8 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.modules.calendar.NotifyAcceptedDeclinedAsCreator.class,
             com.openexchange.groupware.settings.tree.modules.calendar.NotifyAcceptedDeclinedAsParticipant.class,
             com.openexchange.groupware.settings.tree.modules.calendar.NotifyNewModifiedDeleted.class,
+            com.openexchange.groupware.settings.tree.modules.calendar.DefaultStatusPrivate.class,
+            com.openexchange.groupware.settings.tree.modules.calendar.DefaultStatusPublic.class,
             com.openexchange.groupware.settings.tree.modules.contacts.GUI.class,
             com.openexchange.groupware.settings.tree.modules.contacts.MailAddressAutoSearch.class,
             com.openexchange.groupware.settings.tree.modules.contacts.Module.class,
@@ -255,12 +257,15 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.modules.infostore.Module.class,
             com.openexchange.groupware.settings.tree.modules.interfaces.ICal.class,
             com.openexchange.groupware.settings.tree.modules.interfaces.SyncML.class,
+            com.openexchange.groupware.settings.tree.modules.interfaces.EAS.class,
+            com.openexchange.groupware.settings.tree.modules.interfaces.USM.class,
             com.openexchange.groupware.settings.tree.modules.interfaces.VCard.class,
             com.openexchange.groupware.settings.tree.modules.mail.Addresses.class,
             com.openexchange.groupware.settings.tree.modules.mail.AllowHTMLImages.class,
             com.openexchange.groupware.settings.tree.modules.mail.AppendMailText.class,
             com.openexchange.groupware.settings.tree.modules.mail.Colorquoted.class,
             com.openexchange.groupware.settings.tree.modules.mail.DefaultAddress.class,
+            com.openexchange.groupware.settings.tree.modules.mail.DefaultSeparator.class,
             com.openexchange.groupware.settings.tree.modules.mail.DeleteMail.class,
             com.openexchange.groupware.settings.tree.modules.mail.UnifiedINBOXEnablement.class,
             com.openexchange.groupware.settings.tree.modules.mail.Emoticons.class,
