@@ -146,6 +146,41 @@ public class TaskException extends AbstractOXException {
      * Error codes for task exceptions.
      * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
      */
+    /**
+     * {@link Code}
+     *
+     * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+     */
+    /**
+     * {@link Code}
+     *
+     * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+     */
+    /**
+     * {@link Code}
+     *
+     * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+     */
+    /**
+     * {@link Code}
+     *
+     * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+     */
+    /**
+     * {@link Code}
+     *
+     * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+     */
+    /**
+     * {@link Code}
+     *
+     * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+     */
+    /**
+     * {@link Code}
+     *
+     * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+     */
     public enum Code {
         /**
          * Error while inserting task: %s.
@@ -399,7 +434,11 @@ public class TaskException extends AbstractOXException {
          */
         COSTS_OFF_LIMIT("The entered value for costs is not within the allowed "
             + "range. Please use a value from -130000.00 to 130000.00.",
-            Category.USER_INPUT, Detail.TRUNCATED, 50);
+            Category.USER_INPUT, Detail.TRUNCATED, 50),
+        /**
+         * In order to accomplish the search, %1$d or more characters are required.
+         */
+        PATTERN_TOO_SHORT("In order to accomplish the search, %1$d or more characters are required.", Category.USER_INPUT, Detail.OTHER, 51);
 
         /**
          * Message of the exception.
