@@ -49,6 +49,7 @@
 
 package com.openexchange.groupware.update;
 
+import static com.openexchange.tools.io.IOUtils.closeReaderStuff;
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileInputStream;
@@ -153,13 +154,7 @@ public final class UpdateTaskCollectionInit implements Initialization {
             LOG.error(e.getMessage(), e);
             return null;
         } finally {
-            if (reader != null) {
-                try {
-                    reader.close();
-                } catch (final IOException e) {
-                    LOG.error(e.getMessage(), e);
-                }
-            }
+            closeReaderStuff(reader);
         }
     }
 
@@ -324,8 +319,34 @@ public final class UpdateTaskCollectionInit implements Initialization {
             registry.addUpdateTask(new com.openexchange.groupware.calendar.update.AlterChangeExceptionFieldLength());
             // Version 58
             // Due to a bug, there are several appointments with the String "null" in the recurrence pattern
-            // instead of sql NULL. This update task repairs these broken lines in the database.
+            // instead of SQL NULL. This update task repairs these broken lines in the database.
             registry.addUpdateTask(new com.openexchange.groupware.calendar.update.RepairRecurrencePatternNullValue());
+            // Version 60
+            // The collation of column uid in table login2user must be changed to utf8_bin to prevent a collision of login
+            // names that are equal except some accent or some German umlauts.
+            registry.addUpdateTask(new com.openexchange.groupware.update.tasks.AlterUidCollation());
+            // Version 62
+            // Runs the task AlterUidCollation again. The schema creating scripts did not contain the fix for v6.10.
+            registry.addUpdateTask(new com.openexchange.groupware.update.tasks.AlterUidCollation2());
+            // Version 70
+            // New config parameters to set the default confirmation status of newly created appointments
+            // for participants in private an public folders
+            registry.addUpdateTask(new com.openexchange.groupware.update.tasks.DefaultConfirmStatusUpdateTask());
+            // Version 72
+            // Creates necessary tables for virtual folder tree
+            registry.addUpdateTask(new com.openexchange.folderstorage.virtual.VirtualTreeCreateTableTask());
+            // Version 74
+            // Creates indexes on tables "prg_contacts" and "del_contacts" to improve auto-complete search
+            registry.addUpdateTask(new com.openexchange.groupware.update.tasks.ContactsAddIndex4AutoCompleteSearch());
+            // Version 76
+            // Drops incorrect admin permission on top level infostore folder
+            registry.addUpdateTask(new com.openexchange.groupware.update.tasks.RemoveAdminPermissionOnInfostoreTask());
+
+
+            // TODO: Enable virtual folder tree update task when needed
+            // Version XY
+            // Migrates existing folder data to new outlook-like folder tree structure
+            // registry.addUpdateTask(new com.openexchange.folderstorage.virtual.VirtualTreeMigrationTask());
         }
         if (LOG.isInfoEnabled()) {
             LOG.info("UpdateTaskCollection successfully started");
