@@ -117,6 +117,10 @@ public final class UserConfiguration implements Serializable, Cloneable {
     private static final int SUBSCRIPTION = 1 << 23;
 
     private static final int PUBLICATION = 1 << 24;
+    
+    private static final int ACTIVE_SYNC = 1 << 25;
+    
+    private static final int USM = 1 << 26;
 
     /*-
      * Field members
@@ -621,16 +625,16 @@ public final class UserConfiguration implements Serializable, Cloneable {
      * Checks if user has access to given module.
      * 
      * @param module The module carrying a value defined in constants <code>
-	 *            {@link FolderObject#TASK}</code> , <code>
-	 *            {@link FolderObject#CALENDAR}</code>
+     *            {@link FolderObject#TASK}</code> , <code>
+     *            {@link FolderObject#CALENDAR}</code>
      *            , <code>
-	 *            {@link FolderObject#CONTACT}</code> , <code>
-	 *            {@link FolderObject#UNBOUND}</code>, <code>
-	 *            {@link FolderObject#SYSTEM_MODULE}</code>
+     *            {@link FolderObject#CONTACT}</code> , <code>
+     *            {@link FolderObject#UNBOUND}</code>, <code>
+     *            {@link FolderObject#SYSTEM_MODULE}</code>
      *            , <code>
-	 *            {@link FolderObject#PROJECT}</code>, <code>
-	 *            {@link FolderObject#MAIL}</code> , <code>
-	 *            {@link FolderObject#INFOSTORE}</code>
+     *            {@link FolderObject#PROJECT}</code>, <code>
+     *            {@link FolderObject#MAIL}</code> , <code>
+     *            {@link FolderObject#INFOSTORE}</code>
      * @return <code>true</code> if user configuration permits access to given module; otherwise <code>false</code>
      */
     public boolean hasModuleAccess(final int module) {
@@ -774,6 +778,35 @@ public final class UserConfiguration implements Serializable, Cloneable {
         setPermission(publication, PUBLICATION);
 
     }
+    
+    /**
+     *  Checks if this user configuration indicates that the user may use Exchange Active Sync
+     */
+    public boolean hasActiveSync() {
+        return hasPermission(ACTIVE_SYNC);
+    }
+    
+    /**
+     * Sets if this user is able to use Exchange Active Sync
+     */
+    public void setActiveSync(boolean eas) {
+        setPermission(eas, ACTIVE_SYNC);
+    }
+    
+    
+    /**
+     * Cheks if this user configuration indicates that the user may use USM.
+     */
+    public boolean hasUSM() {
+        return hasPermission(USM);
+    }
+
+    /**
+     * Sets if this user is able to user USM.
+     */
+    public void setUSM(boolean usm) {
+        setPermission(usm, USM);
+    }
 
     /**
      * Checks if this user configuration indicates that groups are allowed to be edited.
