@@ -196,26 +196,25 @@ public final class ImageRegistry {
         ConcurrentMap<String, ImageData> m = sessionBoundImagesMap.get(sessionId);
         boolean check = true;
         if (m == null) {
-            synchronized (sessionBoundImagesMap) {
-                m = sessionBoundImagesMap.get(sessionId);
-                if (m == null) {
-                    m = new ConcurrentHashMap<String, ImageData>();
-                    sessionBoundImagesMap.put(sessionId, m);
-                    check = false;
-                }
+            final ConcurrentMap<String, ImageData> newInst = new ConcurrentHashMap<String, ImageData>();
+            m = sessionBoundImagesMap.putIfAbsent(sessionId, newInst);
+            if (null == m) {
+                m = newInst;
+                check = false;
             }
         }
         ImageData imageData;
-        if (check && (imageData = m.get(imageArguments.getID())) != null) {
+        final String id = imageArguments.getID();
+        if (check && (imageData = m.get(id)) != null) {
             if (LOG.isDebugEnabled()) {
-                LOG.debug("Image data fetched from registry for UID: " + imageArguments.getID());
+                LOG.debug("Image data fetched from registry for UID: " + id);
             }
             return imageData.touch();
         }
         imageData = new ImageData(imageSource, imageArguments, timeToLive);
-        m.put(imageArguments.getID(), imageData);
+        m.put(id, imageData);
         if (LOG.isDebugEnabled()) {
-            LOG.debug("Image data put into registry with UID: " + imageArguments.getID());
+            LOG.debug("Image data put into registry with UID: " + id);
         }
         return imageData;
     }
@@ -248,26 +247,25 @@ public final class ImageRegistry {
         ConcurrentMap<String, ImageData> m = contextBoundImagesMap.get(cid);
         boolean check = true;
         if (m == null) {
-            synchronized (contextBoundImagesMap) {
-                m = contextBoundImagesMap.get(cid);
-                if (m == null) {
-                    m = new ConcurrentHashMap<String, ImageData>();
-                    contextBoundImagesMap.put(cid, m);
-                    check = false;
-                }
+            final ConcurrentMap<String, ImageData> newInst = new ConcurrentHashMap<String, ImageData>();
+            m = contextBoundImagesMap.putIfAbsent(cid, newInst);
+            if (null == m) {
+                m = newInst;
+                check = false;
             }
         }
         ImageData imageData;
-        if (check && (imageData = m.get(imageArguments.getID())) != null) {
+        final String id = imageArguments.getID();
+        if (check && (imageData = m.get(id)) != null) {
             if (LOG.isDebugEnabled()) {
-                LOG.debug("Image data fetched from registry for UID: " + imageArguments.getID());
+                LOG.debug("Image data fetched from registry for UID: " + id);
             }
             return imageData.touch();
         }
         imageData = new ImageData(imageSource, imageArguments, timeToLive);
-        m.put(imageArguments.getID(), imageData);
+        m.put(id, imageData);
         if (LOG.isDebugEnabled()) {
-            LOG.debug("Image data put into registry with UID: " + imageArguments.getID());
+            LOG.debug("Image data put into registry with UID: " + id);
         }
         return imageData;
     }
