@@ -49,6 +49,7 @@
 
 package com.openexchange.mail;
 
+import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.mail.utils.MailFolderUtility.prepareFullname;
 import static com.openexchange.mail.utils.MailFolderUtility.prepareMailFolderParam;
 import java.text.Collator;
@@ -67,6 +68,8 @@ import java.util.Set;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import com.openexchange.cache.OXCachingException;
+import com.openexchange.configuration.ConfigurationException;
+import com.openexchange.configuration.ServerConfig;
 import com.openexchange.dataretention.DataRetentionException;
 import com.openexchange.dataretention.DataRetentionService;
 import com.openexchange.dataretention.RetentionData;
@@ -77,6 +80,7 @@ import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.userconfiguration.UserConfigurationException;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
+import com.openexchange.mail.MailException.Code;
 import com.openexchange.mail.api.IMailFolderStorage;
 import com.openexchange.mail.api.IMailMessageStorage;
 import com.openexchange.mail.api.MailAccess;
@@ -91,6 +95,7 @@ import com.openexchange.mail.dataobjects.compose.ComposeType;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
 import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MIMETypes;
+import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
 import com.openexchange.mail.mime.processing.MimeForward;
 import com.openexchange.mail.parser.MailMessageParser;
@@ -116,6 +121,7 @@ import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorAdapter;
 import com.openexchange.tools.iterator.SearchIteratorDelegator;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.sql.SearchStrings;
 import com.openexchange.user.UserService;
 
 /**
@@ -143,7 +149,7 @@ final class MailServletInterfaceImpl extends MailServletInterface {
 
     private MailConfig mailConfig;
 
-    private MailAccess<?, ?> mailAccess;
+    private MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess;
 
     private int accountId;
 
@@ -424,8 +430,7 @@ final class MailServletInterfaceImpl extends MailServletInterface {
         /*
          * Check if denoted parent can hold default folders like Trash, Sent, etc.
          */
-        if (!MailFolder.DEFAULT_FOLDER_ID.equals(parentFullname) && !prepareMailFolderParam(getInboxFolder(accountId)).getFullname().equals(
-            parentFullname)) {
+        if (!MailFolder.DEFAULT_FOLDER_ID.equals(parentFullname) && !INBOX_ID.equals(parentFullname)) {
             /*
              * Denoted parent is not capable to hold default folders. Therefore output as it is.
              */
@@ -715,6 +720,7 @@ final class MailServletInterfaceImpl extends MailServletInterface {
 
     @Override
     public SearchIterator<MailMessage> getMessages(final String folder, final int[] fromToIndices, final int sortCol, final int order, final int[] searchCols, final String[] searchPatterns, final boolean linkSearchTermsWithOR, final int[] fields) throws MailException {
+        checkPatternLength(searchPatterns);
         final FullnameArgument argument = prepareMailFolderParam(folder);
         final int accountId = argument.getAccountId();
         initConnection(accountId);
@@ -917,6 +923,7 @@ final class MailServletInterfaceImpl extends MailServletInterface {
 
     @Override
     public SearchIterator<MailMessage> getThreadedMessages(final String folder, final int[] fromToIndices, final int sortCol, final int order, final int[] searchCols, final String[] searchPatterns, final boolean linkSearchTermsWithOR, final int[] fields) throws MailException {
+        checkPatternLength(searchPatterns);
         final FullnameArgument argument = prepareMailFolderParam(folder);
         final int accountId = argument.getAccountId();
         initConnection(accountId);
@@ -987,6 +994,23 @@ final class MailServletInterfaceImpl extends MailServletInterface {
         return SearchIteratorAdapter.createArrayIterator(mails);
     }
 
+    private void checkPatternLength(String[] patterns) throws MailException {
+        final int minimumSearchCharacters;
+        try {
+            minimumSearchCharacters = ServerConfig.getInt(ServerConfig.Property.MINIMUM_SEARCH_CHARACTERS);
+        } catch (ConfigurationException e) {
+            throw new MailException(e);
+        }
+        if (0 == minimumSearchCharacters || null == patterns) {
+            return;
+        }
+        for (String pattern : patterns) {
+            if (null != pattern && SearchStrings.lengthWithoutWildcards(pattern) < minimumSearchCharacters) {
+                throw new MailException(Code.PATTERN_TOO_SHORT, I(minimumSearchCharacters));
+            }
+        }
+    }
+
     @Override
     public String getTrashFolder(final int accountId) throws MailException {
         if (isDefaultFoldersChecked(accountId)) {
@@ -1069,7 +1093,7 @@ final class MailServletInterfaceImpl extends MailServletInterface {
         }
         final MailPath msgref = draftMail.getMsgref();
         final MailMessage origMail;
-        if (null == msgref) {
+        if (null == msgref || !draftFullname.equals(msgref.getFolder())) {
             origMail = null;
         } else {
             origMail = mailAccess.getMessageStorage().getMessage(msgref.getFolder(), msgref.getMailID(), false);
@@ -1508,22 +1532,22 @@ final class MailServletInterfaceImpl extends MailServletInterface {
                 try {
                     final Set<InternetAddress> validAddrs = new HashSet<InternetAddress>(4);
                     if (usm.getSendAddr() != null && usm.getSendAddr().length() > 0) {
-                        validAddrs.add(new InternetAddress(usm.getSendAddr()));
+                        validAddrs.add(new QuotedInternetAddress(usm.getSendAddr()));
                     }
                     final User user = UserStorage.getStorageUser(session.getUserId(), session.getContextId());
-                    validAddrs.add(new InternetAddress(user.getMail()));
+                    validAddrs.add(new QuotedInternetAddress(user.getMail()));
                     final String[] aliases = user.getAliases();
                     for (final String alias : aliases) {
-                        validAddrs.add(new InternetAddress(alias));
+                        validAddrs.add(new QuotedInternetAddress(alias));
                     }
-                    if (!validAddrs.contains(new InternetAddress(fromAddr))) {
+                    if (!validAddrs.contains(new QuotedInternetAddress(fromAddr))) {
                         throw new MailException(MailException.Code.INVALID_SENDER, fromAddr);
                     }
                 } catch (final AddressException e) {
                     throw MIMEMailException.handleMessagingException(e);
                 }
             } else {
-                if (!new InternetAddress(ma.getPrimaryAddress()).equals(new InternetAddress(fromAddr))) {
+                if (!new QuotedInternetAddress(ma.getPrimaryAddress()).equals(new QuotedInternetAddress(fromAddr))) {
                     throw new MailException(MailException.Code.INVALID_SENDER, fromAddr);
                 }
             }
