@@ -147,7 +147,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * @param mailAccess An instance of {@link MailAccess}
      * @throws MailException If implementation-specific startup fails
      */
-    static void startupImpl(final MailAccess<?, ?> mailAccess) throws MailException {
+    static void startupImpl(final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws MailException {
         mailAccess.startup();
     }
 
@@ -157,7 +157,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * @param mailAccess An instance of {@link MailAccess}
      * @throws MailException If implementation-specific shutdown fails
      */
-    static void shutdownImpl(final MailAccess<?, ?> mailAccess) throws MailException {
+    static void shutdownImpl(final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws MailException {
         mailAccess.shutdown();
     }
 
@@ -181,7 +181,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * @return A proper instance of {@link MailAccess}
      * @throws MailException If instantiation fails or a caching error occurs
      */
-    public static final MailAccess<?, ?> getInstance(final Session session) throws MailException {
+    public static final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> getInstance(final Session session) throws MailException {
         return getInstance(session, MailAccount.DEFAULT_ID);
     }
 
@@ -206,7 +206,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * @return A proper instance of {@link MailAccess}
      * @throws MailException If instantiation fails or a caching error occurs
      */
-    public static final MailAccess<?, ?> getInstance(final Session session, final int accountId) throws MailException {
+    public static final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> getInstance(final Session session, final int accountId) throws MailException {
         /*
          * Check for proper initialization
          */
@@ -353,6 +353,16 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         connect0(true);
     }
 
+    /**
+     * Opens this access. May be invoked on an already opened access.
+     * 
+     * @param checkDefaultFolders <code>true</code> to check existence of default folders; otherwise <code>false</code> to omit check
+     * @throws MailException If the connection could not be established for various reasons
+     */
+    public final void connect(final boolean checkDefaultFolders) throws MailException {
+        connect0(checkDefaultFolders);
+    }
+
     /**
      * Convenience method to obtain root folder in a fast way; meaning no default folder check is performed which is not necessary to return
      * the root folder.
@@ -382,35 +392,40 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
     private final void connect0(final boolean checkDefaultFolder) throws MailException {
         applyNewThread();
         if (isConnected()) {
-            getFolderStorage().checkDefaultFolders();
-            MailAccessWatcher.addMailAccess(this);
-            return;
-        }
-        checkFieldsBeforeConnect(getMailConfig());
-        connectInternal();
-        if (checkDefaultFolder) {
-            try {
-                getFolderStorage().checkDefaultFolders();
-            } catch (final MailException e) {
-                throw e;
-            } catch (final Exception e) {
-                final MailConfig mailConfig = getMailConfig();
-                final MailException mailExc = new MailException(
-                    MailException.Code.DEFAULT_FOLDER_CHECK_FAILED,
-                    e,
-                    mailConfig.getServer(),
-                    Integer.valueOf(session.getUserId()),
-                    mailConfig.getLogin(),
-                    Integer.valueOf(session.getContextId()),
-                    e.getMessage());
-                LOG.error(mailExc.getMessage(), mailExc);
-                closeInternal();
-                throw mailExc;
+            if (checkDefaultFolder) {
+                checkDefaultFolderOnConnect();
+            }
+        } else {
+            checkFieldsBeforeConnect(getMailConfig());
+            connectInternal();
+            if (checkDefaultFolder) {
+                checkDefaultFolderOnConnect();
             }
         }
         MailAccessWatcher.addMailAccess(this);
     }
 
+    private void checkDefaultFolderOnConnect() throws MailException {
+        try {
+            getFolderStorage().checkDefaultFolders();
+        } catch (final MailException e) {
+            throw e;
+        } catch (final Exception e) {
+            final MailConfig mailConfig = getMailConfig();
+            final MailException mailExc = new MailException(
+                MailException.Code.DEFAULT_FOLDER_CHECK_FAILED,
+                e,
+                mailConfig.getServer(),
+                Integer.valueOf(session.getUserId()),
+                mailConfig.getLogin(),
+                Integer.valueOf(session.getContextId()),
+                e.getMessage());
+            LOG.error(mailExc.getMessage(), mailExc);
+            closeInternal();
+            throw mailExc;
+        }
+    }
+
     /**
      * Internal connect method to establish a mail connection.
      * 
