@@ -265,12 +265,14 @@ public abstract class MailConfig {
          * Fetch mail account
          */
         final MailAccount mailAccount;
+        final int userId = session.getUserId();
+        final int contextId = session.getContextId();
         try {
             final MailAccountStorageService storage = ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class, true);
             if (accountId == MailAccount.DEFAULT_ID) {
-                mailAccount = storage.getDefaultMailAccount(session.getUserId(), session.getContextId());
+                mailAccount = storage.getDefaultMailAccount(userId, contextId);
             } else {
-                mailAccount = storage.getMailAccount(accountId, session.getUserId(), session.getContextId());
+                mailAccount = storage.getMailAccount(accountId, userId, contextId);
             }
         } catch (final ServiceException e) {
             throw new MailException(e);
@@ -278,20 +280,16 @@ public abstract class MailConfig {
             throw new MailException(e);
         }
         mailConfig.accountId = accountId;
-        fillLoginAndPassword(
-            mailConfig,
-            session.getPassword(),
-            UserStorage.getStorageUser(session.getUserId(), session.getContextId()).getLoginInfo(),
-            mailAccount);
+        fillLoginAndPassword(mailConfig, session.getPassword(), UserStorage.getStorageUser(userId, contextId).getLoginInfo(), mailAccount);
         String serverURL = MailConfig.getMailServerURL(mailAccount);
         if (serverURL == null) {
             if (ServerSource.GLOBAL.equals(MailProperties.getInstance().getMailServerSource())) {
                 throw new MailConfigException(
-                    new StringBuilder(128).append("Property \"").append("com.openexchange.mail.mailServer").append(
+                    new StringBuilder(64).append("Property \"").append("com.openexchange.mail.mailServer").append(
                         "\" not set in mail properties").toString());
             }
-            throw new MailConfigException(new StringBuilder(128).append("Cannot determine mail server URL for user ").append(
-                session.getUserId()).append(" in context ").append(session.getContextId()).toString());
+            throw new MailConfigException(new StringBuilder(64).append("Cannot determine mail server URL for user ").append(userId).append(
+                " in context ").append(contextId).toString());
         }
         {
             /*
@@ -450,15 +448,17 @@ public abstract class MailConfig {
      * @return <code>true</code> if part modifier shall be used; otherwise <code>false</code>
      */
     public static final boolean usePartModifier() {
-        if (usePartModifier == null) {
+        Boolean tmp = usePartModifier;
+        if (tmp == null) {
             synchronized (MailConfig.class) {
-                if (usePartModifier == null) {
+                tmp = usePartModifier;
+                if (tmp == null) {
                     final PartModifier pm = PartModifier.getInstance();
-                    usePartModifier = Boolean.valueOf(pm != null && !DummyPartModifier.class.isInstance(pm));
+                    tmp = usePartModifier = Boolean.valueOf(pm != null && !DummyPartModifier.class.isInstance(pm));
                 }
             }
         }
-        return usePartModifier.booleanValue();
+        return tmp.booleanValue();
     }
 
     private final static boolean isValidProtocol(final String protocol) {
@@ -628,7 +628,8 @@ public abstract class MailConfig {
         result = prime * result + ((login == null) ? 0 : login.hashCode());
         result = prime * result + ((password == null) ? 0 : password.hashCode());
         result = prime * result + (getPort());
-        result = prime * result + ((getServer() == null) ? 0 : getServer().hashCode());
+        final String server = getServer();
+        result = prime * result + ((server == null) ? 0 : server.hashCode());
         return result;
     }
 
