@@ -60,6 +60,7 @@ import java.util.Date;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 import java.util.regex.Matcher;
@@ -75,6 +76,7 @@ import javax.mail.Message.RecipientType;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.InternetHeaders;
+import javax.mail.internet.MailDateFormat;
 import javax.mail.internet.MimeBodyPart;
 import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
@@ -112,9 +114,11 @@ import com.openexchange.mail.dataobjects.compose.ReferencedMailPart;
 import com.openexchange.mail.dataobjects.compose.ComposedMailPart.ComposedPartType;
 import com.openexchange.mail.mime.ContentDisposition;
 import com.openexchange.mail.mime.ContentType;
+import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MIMEType2ExtMap;
 import com.openexchange.mail.mime.MIMETypes;
 import com.openexchange.mail.mime.MessageHeaders;
+import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.datasource.MessageDataSource;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.text.parser.HTMLParser;
@@ -300,8 +304,9 @@ public class MIMEMessageFiller {
      * @param mail The composed mail
      * @param mimeMessage The MIME message
      * @throws MessagingException If headers cannot be set
+     * @throws MailException If a mail error occurs
      */
-    public void setMessageHeaders(final ComposedMailMessage mail, final MimeMessage mimeMessage) throws MessagingException {
+    public void setMessageHeaders(final ComposedMailMessage mail, final MimeMessage mimeMessage) throws MessagingException, MailException {
         /*
          * Set from/sender
          */
@@ -309,7 +314,7 @@ public class MIMEMessageFiller {
             InternetAddress sender = null;
             if (usm.getSendAddr() != null && usm.getSendAddr().length() > 0) {
                 try {
-                    sender = new InternetAddress(usm.getSendAddr(), true);
+                    sender = new QuotedInternetAddress(usm.getSendAddr(), true);
                 } catch (final AddressException e) {
                     LOG.error("Default send address cannot be parsed", e);
                 }
@@ -351,7 +356,7 @@ public class MIMEMessageFiller {
             }
         } else {
             try {
-                mimeMessage.setReplyTo(InternetAddress.parse(usm.getReplyToAddr(), true));
+                mimeMessage.setReplyTo(QuotedInternetAddress.parse(usm.getReplyToAddr(), true));
             } catch (final AddressException e) {
                 LOG.error("Default Reply-To address cannot be parsed", e);
                 try {
@@ -377,7 +382,10 @@ public class MIMEMessageFiller {
          * Set sent date
          */
         if (mail.containsSentDate()) {
-            mimeMessage.setSentDate(mail.getSentDate());
+            final MailDateFormat mdf = MIMEMessageUtility.getMailDateFormat(session);
+            synchronized (mdf) {
+                mimeMessage.setHeader("Date", mdf.format(mail.getSentDate()));
+            }
         }
         /*
          * Set flags
@@ -508,32 +516,47 @@ public class MIMEMessageFiller {
      * 
      * @param mail The source mail
      * @param mimeMessage The MIME message
-     * @throws AddressException
-     * @throws MessagingException
+     * @throws MailException If a mail error occurs
      */
-    public void setSendHeaders(final ComposedMailMessage mail, final MimeMessage mimeMessage) throws AddressException, MessagingException {
-        /*
-         * Set the Reply-To header for future replies to this new message
-         */
-        final InternetAddress[] ia;
-        if (usm.getReplyToAddr() == null) {
-            ia = mail.getFrom();
-        } else {
-            ia = MIMEMessageUtility.parseAddressList(usm.getReplyToAddr(), false);
-        }
-        mimeMessage.setReplyTo(ia);
-        /*
-         * Set sent date if not done, yet
-         */
-        if (mimeMessage.getSentDate() == null) {
-            mimeMessage.setSentDate(new Date());
-        }
-        /*
-         * Set default subject if none set
-         */
-        final String subject;
-        if ((subject = mimeMessage.getSubject()) == null || subject.length() == 0) {
-            mimeMessage.setSubject(new StringHelper(UserStorage.getStorageUser(session.getUserId(), ctx).getLocale()).getString(MailStrings.DEFAULT_SUBJECT));
+    public void setSendHeaders(final ComposedMailMessage mail, final MimeMessage mimeMessage) throws MailException {
+        try {
+            /*
+             * Set the Reply-To header for future replies to this new message
+             */
+            final InternetAddress[] ia;
+            if (usm.getReplyToAddr() == null) {
+                ia = mail.getFrom();
+            } else {
+                ia = MIMEMessageUtility.parseAddressList(usm.getReplyToAddr(), false);
+            }
+            mimeMessage.setReplyTo(ia);
+            /*
+             * Set sent date if not done, yet
+             */
+            final Date sentDate = mimeMessage.getSentDate();
+            if (sentDate == null) {
+                final MailDateFormat mdf = MIMEMessageUtility.getMailDateFormat(session);
+                synchronized (mdf) {
+                    mimeMessage.setHeader("Date", mdf.format(new Date()));
+                }
+            } else {
+                // Ensure proper time zone
+                final MailDateFormat mdf = MIMEMessageUtility.getMailDateFormat(session);
+                synchronized (mdf) {
+                    mimeMessage.setHeader("Date", mdf.format(sentDate));
+                }
+            }
+            /*
+             * Set default subject if none set
+             */
+            final String subject = mimeMessage.getSubject();
+            if ((null == subject) || (0 == subject.length())) {
+                mimeMessage.setSubject(new StringHelper(UserStorage.getStorageUser(session.getUserId(), ctx).getLocale()).getString(MailStrings.DEFAULT_SUBJECT));
+            }
+        } catch (final AddressException e) {
+            throw MIMEMailException.handleMessagingException(e);
+        } catch (final MessagingException e) {
+            throw MIMEMailException.handleMessagingException(e);
         }
     }
 
@@ -1294,11 +1317,28 @@ public class MIMEMessageFiller {
         /*
          * Determine filename
          */
-        String fileName;
-        try {
-            fileName = MimeUtility.encodeText(imageProvider.getFileName(), MailProperties.getInstance().getDefaultMimeCharset(), "Q");
-        } catch (final UnsupportedEncodingException e) {
-            fileName = imageProvider.getFileName();
+        String fileName = imageProvider.getFileName();
+        if (null == fileName) {
+            /*
+             * Generate dummy file name
+             */
+            final List<String> exts = MIMEType2ExtMap.getFileExtensions(imageProvider.getContentType().toLowerCase(Locale.ENGLISH));
+            final StringBuilder sb = new StringBuilder("image.");
+            if (exts == null) {
+                sb.append("dat");
+            } else {
+                sb.append(exts.get(0));
+            }
+            fileName = sb.toString();
+        } else {
+            /*
+             * Encode image's file name for being mail-safe
+             */
+            try {
+                fileName = MimeUtility.encodeText(fileName, MailProperties.getInstance().getDefaultMimeCharset(), "Q");
+            } catch (final UnsupportedEncodingException e) {
+                fileName = imageProvider.getFileName();
+            }
         }
         /*
          * ... and cid
