@@ -50,6 +50,7 @@
 package com.openexchange.mail.mime.processing;
 
 import static com.openexchange.mail.mime.utils.MIMEMessageUtility.parseAddressList;
+import static com.openexchange.mail.mime.utils.MIMEMessageUtility.unfold;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -88,6 +89,7 @@ import com.openexchange.mail.mime.MIMEDefaultSession;
 import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MIMETypes;
 import com.openexchange.mail.mime.MessageHeaders;
+import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.parser.MailMessageParser;
@@ -210,7 +212,7 @@ public final class MimeReply {
             if (subjectHdrValue == null) {
                 subjectHdrValue = "";
             }
-            final String rawSubject = MIMEMessageUtility.unfold(subjectHdrValue);
+            final String rawSubject = unfold(subjectHdrValue);
             {
                 final String decodedSubject = MIMEMessageUtility.decodeMultiEncodedHeader(rawSubject);
                 final String newSubject = decodedSubject.regionMatches(true, 0, subjectPrefix, 0, 4) ? decodedSubject : new StringBuilder().append(
@@ -231,7 +233,7 @@ public final class MimeReply {
                 }
             } else {
                 final String[] replyTo = originalMsg.getHeader(MessageHeaders.HDR_REPLY_TO);
-                if (replyTo == null) {
+                if (MIMEMessageUtility.isEmptyHeader(replyTo)) {
                     /*
                      * Set from as recipient
                      */
@@ -240,7 +242,7 @@ public final class MimeReply {
                     /*
                      * Message holds header 'Reply-To'
                      */
-                    recipientAddrs = InternetAddress.parseHeader(MIMEMessageUtility.unfold(replyTo[0]), true);
+                    recipientAddrs = QuotedInternetAddress.parseHeader(unfold(replyTo[0]), true);
                 }
             }
             if (replyAll) {
@@ -319,7 +321,7 @@ public final class MimeReply {
                 filteredAddrs.clear();
                 hdrVal = originalMsg.getHeader(MessageHeaders.HDR_CC, MessageHeaders.HDR_ADDR_DELIM);
                 if (hdrVal != null) {
-                    filteredAddrs.addAll(filter(filter, parseAddressList(MIMEMessageUtility.unfold(hdrVal), true)));
+                    filteredAddrs.addAll(filter(filter, parseAddressList(unfold(hdrVal), true)));
                 }
                 if (!filteredAddrs.isEmpty()) {
                     replyMsg.addRecipients(RecipientType.CC, filteredAddrs.toArray(new InternetAddress[filteredAddrs.size()]));
@@ -330,7 +332,7 @@ public final class MimeReply {
                 filteredAddrs.clear();
                 hdrVal = originalMsg.getHeader(MessageHeaders.HDR_BCC, MessageHeaders.HDR_ADDR_DELIM);
                 if (hdrVal != null) {
-                    filteredAddrs.addAll(filter(filter, parseAddressList(MIMEMessageUtility.unfold(hdrVal), true)));
+                    filteredAddrs.addAll(filter(filter, parseAddressList(unfold(hdrVal), true)));
                 }
                 if (!filteredAddrs.isEmpty()) {
                     replyMsg.addRecipients(RecipientType.BCC, filteredAddrs.toArray(new InternetAddress[filteredAddrs.size()]));
@@ -593,7 +595,7 @@ public final class MimeReply {
             /*
              * Get html content
              */
-            for (int i = 0; i < count && !found; i++) {
+            for (int i = 0; i < count; i++) {
                 final MailPart part = multipartPart.getEnclosedMailPart(i);
                 partContentType.setContentType(part.getContentType());
                 if (partContentType.isMimeType(MIMETypes.MIME_TEXT_HTM_ALL) && MimeProcessingUtility.isInline(part, partContentType)) {
@@ -625,12 +627,11 @@ public final class MimeReply {
                         replyTexts);
                 }
             }
-        }
-        if (!found) {
+        } else {
             /*
              * Get any text content
              */
-            for (int i = 0; i < count && !found; i++) {
+            for (int i = 0; i < count; i++) {
                 final MailPart part = multipartPart.getEnclosedMailPart(i);
                 partContentType.setContentType(part.getContentType());
                 if (partContentType.isMimeType(MIMETypes.MIME_TEXT_ALL) && MimeProcessingUtility.isInline(part, partContentType)) {
