@@ -59,6 +59,13 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Locale;
 import java.util.Set;
+import java.util.TimeZone;
+import java.util.concurrent.Callable;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.Future;
+import java.util.concurrent.FutureTask;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.mail.BodyPart;
@@ -66,9 +73,12 @@ import javax.mail.MessagingException;
 import javax.mail.Multipart;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
+import javax.mail.internet.MailDateFormat;
 import javax.mail.internet.MimeUtility;
 import javax.mail.internet.ParseException;
 import com.openexchange.filemanagement.ManagedFileManagement;
+import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.image.ImageService;
 import com.openexchange.image.internal.ImageData;
 import com.openexchange.mail.MailException;
@@ -80,8 +90,10 @@ import com.openexchange.mail.mime.HeaderName;
 import com.openexchange.mail.mime.MIMETypes;
 import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.PlainTextAddress;
+import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 import com.sun.mail.imap.protocol.BODYSTRUCTURE;
 
@@ -105,6 +117,8 @@ public final class MIMEMessageUtility {
         ENCODINGS = java.util.Collections.unmodifiableSet(tmp);
     }
 
+    private static final ConcurrentMap<String, Future<MailDateFormat>> MDF_MAP = new ConcurrentHashMap<String, Future<MailDateFormat>>();
+
     /**
      * No instantiation
      */
@@ -112,6 +126,112 @@ public final class MIMEMessageUtility {
         super();
     }
 
+    /**
+     * Gets the {@link MailDateFormat} for specified session.
+     * <p>
+     * Note that returned instance of {@link MailDateFormat} is shared, therefore use a surrounding synchronized block to preserve thread
+     * safety:
+     * 
+     * <pre>
+     * ...
+     * final MailDateFormat mdf = MIMEMessageUtility.getMailDateFormat(session);
+     * synchronized(mdf) {
+     *  mimeMessage.setHeader(&quot;Date&quot;, mdf.format(sendDate));
+     * }
+     * ...
+     * </pre>
+     * 
+     * @param session The user session
+     * @return The {@link MailDateFormat} for specified session
+     * @throws MailException If {@link MailDateFormat} cannot be returned
+     */
+    public static MailDateFormat getMailDateFormat(final Session session) throws MailException {
+        final User user;
+        if (session instanceof ServerSession) {
+            user = ((ServerSession) session).getUser();
+        } else {
+            user = UserStorage.getStorageUser(session.getUserId(), session.getContextId());
+        }
+        return getMailDateFormat(user.getTimeZone());
+    }
+
+    /**
+     * Gets the {@link MailDateFormat} for specified time zone identifier.
+     * <p>
+     * Note that returned instance of {@link MailDateFormat} is shared, therefore use a surrounding synchronized block to preserve thread
+     * safety:
+     * 
+     * <pre>
+     * ...
+     * final MailDateFormat mdf = MIMEMessageUtility.getMailDateFormat(timeZoneId);
+     * synchronized(mdf) {
+     *  mimeMessage.setHeader(&quot;Date&quot;, mdf.format(sendDate));
+     * }
+     * ...
+     * </pre>
+     * 
+     * @param timeZoneId The time zone identifier
+     * @return The {@link MailDateFormat} for specified time zone identifier
+     * @throws MailException If {@link MailDateFormat} cannot be returned
+     */
+    public static MailDateFormat getMailDateFormat(final String timeZoneId) throws MailException {
+        Future<MailDateFormat> future = MDF_MAP.get(timeZoneId);
+        if (null == future) {
+            final FutureTask<MailDateFormat> ft = new FutureTask<MailDateFormat>(new Callable<MailDateFormat>() {
+
+                public MailDateFormat call() throws Exception {
+                    final MailDateFormat mdf = new MailDateFormat();
+                    mdf.setTimeZone(TimeZone.getTimeZone(timeZoneId));
+                    return mdf;
+                }
+            });
+            future = MDF_MAP.putIfAbsent(timeZoneId, ft);
+            if (null == future) {
+                future = ft;
+                ft.run();
+            }
+        }
+        try {
+            return future.get();
+        } catch (final InterruptedException e) {
+            Thread.currentThread().interrupt();
+            throw new MailException(MailException.Code.UNEXPECTED_ERROR, e, e.getMessage());
+        } catch (final ExecutionException e) {
+            final Throwable cause = e.getCause();
+            throw new MailException(MailException.Code.UNEXPECTED_ERROR, cause, cause.getMessage());
+        }
+    }
+
+    /**
+     * Checks if specified headers are empty. The passed headers are considered as all the values for a certain header or <code>null</code>
+     * if no headers exist.
+     * 
+     * @param headers The values for a certain header
+     * @return <code>true</code> if specified headers are empty; otherwise <code>false</code>
+     */
+    public static boolean isEmptyHeader(final String[] headers) {
+        if (null == headers || 0 == headers.length) {
+            return true;
+        }
+        boolean isEmpty = true;
+        for (int i = 0; isEmpty && i < headers.length; i++) {
+            isEmpty = isEmpty(headers[i]);
+        }
+        return isEmpty;
+    }
+
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final char[] chars = string.toCharArray();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < chars.length; i++) {
+            isWhitespace = Character.isWhitespace(chars[i]);
+        }
+        return isWhitespace;
+    }
+
     private static final Pattern PATTERN_EMBD_IMG = Pattern.compile(
         "(<img[^>]+src=\"?cid:)([^\"]+)(\"?[^>]*/?>)",
         Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
@@ -477,22 +597,37 @@ public final class MIMEMessageUtility {
         final StringBuilder sb = new StringBuilder(len);
         int prev = 0;
         do {
-            final char c1 = eword.charAt(pos + 1);
-            final char c2 = eword.charAt(pos + 2);
-            final int nextPos;
-            if (isHex(c1) && isHex(c2)) {
-                nextPos = pos + 3;
-                sb.append(eword.substring(prev, nextPos));
-            } else {
-                nextPos = pos + 1;
-                if (ENCODINGS.contains(HeaderName.valueOf(charset))) {
-                    sb.append(eword.substring(prev, pos)).append("=3D");
+            final int pos1 = pos + 1;
+            final int pos2 = pos + 2;
+            if (pos2 < len) {
+                final char c1 = eword.charAt(pos1);
+                final char c2 = eword.charAt(pos2);
+                final int nextPos;
+                if (isHex(c1) && isHex(c2)) {
+                    final int pos3 = pos + 3;
+                    if (pos3 > len) {
+                        nextPos = len;
+                    } else {
+                        nextPos = pos3;
+                    }
+                    sb.append(eword.substring(prev, nextPos));
                 } else {
-                    sb.append(eword.substring(prev, pos)).append(qencode('=', charset));
+                    nextPos = pos1;
+                    if (ENCODINGS.contains(HeaderName.valueOf(charset))) {
+                        sb.append(eword.substring(prev, pos)).append("=3D");
+                    } else {
+                        sb.append(eword.substring(prev, pos)).append(qencode('=', charset));
+                    }
                 }
+                prev = nextPos;
+                pos = nextPos < len ? eword.indexOf('=', nextPos) : -1;
+            } else {
+                if (prev < len) {
+                    sb.append(eword.substring(prev));
+                    prev = len;
+                }
+                pos = -1;
             }
-            prev = nextPos;
-            pos = nextPos < len ? eword.indexOf('=', nextPos) : -1;
         } while (pos != -1);
         if (prev < len) {
             sb.append(eword.substring(prev));
@@ -561,7 +696,7 @@ public final class MIMEMessageUtility {
         final String al = replaceWithComma(unfold(addresslist));
         InternetAddress[] addrs = null;
         try {
-            addrs = InternetAddress.parse(al, strict);
+            addrs = QuotedInternetAddress.parse(al, strict);
         } catch (final AddressException e) {
             if (LOG.isDebugEnabled()) {
                 LOG.debug(new StringBuilder(128).append("Internet addresses could not be properly parsed, ").append(
