@@ -422,8 +422,8 @@ public final class JSONMessageHandler implements MailMessageHandler {
                         try {
                             priority = Integer.parseInt(tmp[0]);
                         } catch (final NumberFormatException nfe) {
-                            if (LOG.isWarnEnabled()) {
-                                LOG.warn("Strange X-Priority header: " + tmp[0], nfe);
+                            if (LOG.isDebugEnabled()) {
+                                LOG.debug("Strange X-Priority header: " + tmp[0]);
                             }
                             priority = MailMessage.PRIORITY_NORMAL;
                         }
