@@ -84,7 +84,6 @@ import com.openexchange.data.conversion.ical.ICalEmitter;
 import com.openexchange.data.conversion.ical.ICalParser;
 import com.openexchange.database.CreateTableService;
 import com.openexchange.database.DatabaseService;
-import com.openexchange.database.osgi.Activator;
 import com.openexchange.dataretention.DataRetentionService;
 import com.openexchange.event.EventFactoryService;
 import com.openexchange.event.impl.EventFactoryServiceImpl;
@@ -98,6 +97,7 @@ import com.openexchange.folder.FolderDeleteListenerService;
 import com.openexchange.folder.FolderService;
 import com.openexchange.folder.internal.FolderDeleteListenerServiceTrackerCustomizer;
 import com.openexchange.folder.internal.FolderServiceImpl;
+import com.openexchange.folderstorage.osgi.FolderStorageActivator;
 import com.openexchange.group.GroupService;
 import com.openexchange.group.internal.GroupServiceImpl;
 import com.openexchange.groupware.AbstractOXException;
@@ -209,6 +209,8 @@ public final class ServerActivator extends DeferredActivator {
 
     private final List<EventHandlerRegistration> eventHandlerList;
 
+    private final List<BundleActivator> activators;
+
     private final Starter starter;
 
     private final AtomicBoolean started;
@@ -226,6 +228,7 @@ public final class ServerActivator extends DeferredActivator {
         serviceTrackerList = new ArrayList<ServiceTracker>();
         componentRegistrationList = new ArrayList<ComponentRegistration>();
         eventHandlerList = new ArrayList<EventHandlerRegistration>();
+        activators = new ArrayList<BundleActivator>(8);
     }
 
     /**
@@ -278,12 +281,8 @@ public final class ServerActivator extends DeferredActivator {
         }
     }
 
-    private BundleActivator databaseActivator;
-
     @Override
     protected void startBundle() throws Exception {
-        // TODO remove the following line if database bundle is finished.
-        (databaseActivator = new Activator()).start(context);
         // get version information from MANIFEST file
         final Dictionary<?, ?> headers = context.getBundle().getHeaders();
         Version.buildnumber = "Rev" + (String) headers.get("OXRevision");
@@ -313,7 +312,9 @@ public final class ServerActivator extends DeferredActivator {
          * Add service trackers
          */
         // Configuration service load
-        serviceTrackerList.add(new ServiceTracker(context, ConfigurationService.class.getName(), new ConfigurationCustomizer(context)));
+        ServiceTracker confTracker = new ServiceTracker(context, ConfigurationService.class.getName(), new ConfigurationCustomizer(context));
+        confTracker.open(); // We need this for {@link Starter#start()}
+        serviceTrackerList.add(confTracker);
         // move this to the required services once the database component gets into its own bundle.
         serviceTrackerList.add(new ServiceTracker(context, DatabaseService.class.getName(), new DatabaseCustomizer(context)));
         // I18n service load
@@ -347,7 +348,7 @@ public final class ServerActivator extends DeferredActivator {
             ICalParser.class){ 
             
             @Override
-            protected ICalParser customize(ICalParser service) {
+            protected ICalParser customize(final ICalParser service) {
                 return new ExtraneousSeriesMasterRecoveryParser(service, ServerServiceRegistry.getInstance());
             }
             
@@ -460,7 +461,11 @@ public final class ServerActivator extends DeferredActivator {
         registrationList.add(context.registerService(UserService.class.getName(), ServerServiceRegistry.getInstance().getService(
             UserService.class,
             true), null));
-        registrationList.add(context.registerService(UserConfigurationService.class.getName(), new UserConfigurationServiceImpl(), null));
+        ServerServiceRegistry.getInstance().addService(UserConfigurationService.class, new UserConfigurationServiceImpl());
+        registrationList.add(context.registerService(
+            UserConfigurationService.class.getName(),
+            ServerServiceRegistry.getInstance().getService(UserConfigurationService.class),
+            null));
         registrationList.add(context.registerService(ContextService.class.getName(), ServerServiceRegistry.getInstance().getService(
             ContextService.class,
             true), null));
@@ -545,6 +550,12 @@ public final class ServerActivator extends DeferredActivator {
         final ContactInterfaceDiscoveryService cids = ContactInterfaceDiscoveryServiceImpl.getInstance();
         registrationList.add(context.registerService(ContactInterfaceDiscoveryService.class.getName(), cids, null));
         ServerServiceRegistry.getInstance().addService(ContactInterfaceDiscoveryService.class, cids);
+        
+        // Fake bundle start
+        activators.add(new FolderStorageActivator());
+        for (final BundleActivator activator : activators) {
+            activator.start(context);
+        }
 
         /*
          * Register components
@@ -571,6 +582,13 @@ public final class ServerActivator extends DeferredActivator {
     protected void stopBundle() throws Exception {
         LOG.info("stopping bundle: com.openexchange.server");
         try {
+            /*
+             * Fake bundle stop
+             */
+            for (final BundleActivator activator : activators) {
+                activator.stop(context);
+            }
+            activators.clear();
             /*
              * Unregister components
              */
@@ -610,9 +628,6 @@ public final class ServerActivator extends DeferredActivator {
             started.set(false);
             adminBundleInstalled = null;
         }
-        // TODO remove this lines if database bundle is finished.
-        databaseActivator.stop(context);
-        databaseActivator = null;
     }
 
     /**
