@@ -143,7 +143,7 @@ public final class OXFolderSQL {
      * @throws DBPoolingException If a pooling error occurs
      * @throws SQLException If a SQL error occurs
      */
-    static int getUserDefaultFolder(final int userId, final int module, final Connection readCon, final Context ctx) throws DBPoolingException, SQLException {
+    public static int getUserDefaultFolder(final int userId, final int module, final Connection readCon, final Context ctx) throws DBPoolingException, SQLException {
         Connection rc = readCon;
         boolean closeReadCon = false;
         PreparedStatement stmt = null;
@@ -307,7 +307,7 @@ public final class OXFolderSQL {
         }
     }
 
-    private static final String SQL_LOOKUPFOLDER = "SELECT fuid FROM oxfolder_tree WHERE cid = ? AND parent = ? AND fname = ? AND module = ?";
+    private static final String SQL_LOOKUPFOLDER = "SELECT fuid,fname FROM oxfolder_tree WHERE cid=? AND parent=? AND fname=? AND module=?";
 
     /**
      * Checks for a duplicate folder in parental folder. A folder is treated as a duplicate if name and module are equal.
@@ -342,16 +342,23 @@ public final class OXFolderSQL {
                 readCon = DBPool.pickup(ctx);
                 closeReadCon = true;
             }
-            stmt = readCon.prepareStatement(folderId > 0 ? new StringBuilder(SQL_LOOKUPFOLDER).append(" AND fuid != ").append(folderId).toString() : SQL_LOOKUPFOLDER);
+            stmt = readCon.prepareStatement(folderId > 0 ? new StringBuilder(SQL_LOOKUPFOLDER).append(" AND fuid!=").append(folderId).toString() : SQL_LOOKUPFOLDER);
             stmt.setInt(1, ctx.getContextId()); // cid
             stmt.setInt(2, parent); // parent
             stmt.setString(3, folderName); // fname
             stmt.setInt(4, module); // module
             rs = stmt.executeQuery();
-            return rs.next() ? rs.getInt(1) : -1;
+            while (rs.next()) {
+                final int fuid = rs.getInt(1);
+                final String fname = rs.getString(2);
+                if (folderName.equals(fname)) {
+                    return fuid;
+                }
+            }
         } finally {
             closeResources(rs, stmt, closeReadCon ? readCon : null, true, ctx);
         }
+        return -1;
     }
 
     private static final String SQL_EXISTS = "SELECT fuid FROM oxfolder_tree WHERE cid = ? AND fuid = ?";
@@ -381,6 +388,32 @@ public final class OXFolderSQL {
         }
     }
 
+    /**
+     * Checks if underlying storage contains a folder whose ID matches given ID
+     * 
+     * @return <tt>true</tt> if folder exists, otherwise <tt>false</tt>
+     */
+    public static boolean exists(final int folderId, final Connection readConArg, final Context ctx, final String table) throws DBPoolingException, SQLException {
+        Connection readCon = readConArg;
+        boolean closeReadCon = false;
+        PreparedStatement stmt = null;
+        ResultSet rs = null;
+        try {
+            if (readCon == null) {
+                readCon = DBPool.pickup(ctx);
+                closeReadCon = true;
+            }
+            stmt = readCon.prepareStatement(new StringBuilder(40).append("SELECT fuid FROM ").append(table).append(
+                " WHERE cid = ? AND fuid = ?").toString());
+            stmt.setInt(1, ctx.getContextId());
+            stmt.setInt(2, folderId);
+            rs = stmt.executeQuery();
+            return rs.next();
+        } finally {
+            closeResources(rs, stmt, closeReadCon ? readCon : null, true, ctx);
+        }
+    }
+
     private static final String SQL_UPDATE_PERMS = "UPDATE oxfolder_permissions SET" + " fp = ?, orp = ?, owp = ?, odp = ?" + " WHERE cid = ? AND fuid = ? AND permission_id = ?";
 
     /**
