@@ -677,7 +677,7 @@ public class OXFolderTools {
     private static SearchIterator getVisiblePrivateFolders(final int userId, final int[] groups, final int[] accessibleModules, final Context ctx, final Timestamp since) throws OXException, SearchIteratorException {
         final StringBuilder condBuilder = new StringBuilder("AND (ot.type = ").append(FolderObject.PRIVATE).append(
             " AND ot.created_from = ").append(userId).append(") AND (ot.parent = ?)").append(
-            (since == null ? STR_EMPTY : " AND (changing_date >= ?)"));
+            (since == null ? STR_EMPTY : " AND (changing_date > ?)"));
         final String sqlSelectStr = getSQLUserVisibleFolders(
             FolderObjectIterator.getFieldsForSQL("ot"),
             StringCollection.getSqlInString(userId, groups),
@@ -718,7 +718,7 @@ public class OXFolderTools {
      */
     private static SearchIterator getVisiblePublicFolders(final int userId, final int[] groups, final int[] accessibleModules, final Context ctx, final Timestamp since) throws OXException, SearchIteratorException {
         final StringBuilder condBuilder = new StringBuilder("AND (ot.type = ").append(FolderObject.PUBLIC).append(") AND (ot.parent = ?)").append(
-            (since == null ? STR_EMPTY : " AND (changing_date >= ?)"));
+            (since == null ? STR_EMPTY : " AND (changing_date > ?)"));
         final String sqlSelectStr = getSQLUserVisibleFolders(
             FolderObjectIterator.getFieldsForSQL("ot"),
             StringCollection.getSqlInString(userId, groups),
@@ -772,7 +772,7 @@ public class OXFolderTools {
             condBuilder.append("AND (ot.type = ").append(FolderObject.PRIVATE).append(" AND ot.created_from != ").append(userId).append(
                 ") ");
         }
-        condBuilder.append("AND (ot.parent = ?)").append((since == null ? STR_EMPTY : " AND (changing_date >= ?)"));
+        condBuilder.append("AND (ot.parent = ?)").append((since == null ? STR_EMPTY : " AND (changing_date > ?)"));
         final String sqlSelectStr = getSQLUserVisibleFolders(
             FolderObjectIterator.getFieldsForSQL("ot"),
             StringCollection.getSqlInString(userId, memberInGroups),
@@ -817,7 +817,7 @@ public class OXFolderTools {
         if (owner > -1) {
             condBuilder.append(" AND (ot.created_from = ").append(owner).append(')');
         }
-        condBuilder.append(since == null ? STR_EMPTY : " AND (changing_date >= ?)");
+        condBuilder.append(since == null ? STR_EMPTY : " AND (changing_date > ?)");
         final String sqlSelectStr = getSQLUserVisibleFolders(
             FolderObjectIterator.getFieldsForSQL("ot"),
             StringCollection.getSqlInString(userId, memberInGroups),
@@ -1243,7 +1243,7 @@ public class OXFolderTools {
             "WHERE ((ot.permission_flag = ").append(FolderObject.PUBLIC_PERMISSION).append(" OR (ot.permission_flag = ").append(
             FolderObject.PRIVATE_PERMISSION).append(" AND ot.created_from = ?)) OR ").append(
             "((op.admin_flag = 1 AND op.permission_id = ?) OR (op.fp > ? AND op.permission_id IN ").append(
-            StringCollection.getSqlInString(userId, memberInGroups)).append("))) AND (changing_date >= ?)").append(" AND (ot.module IN ").append(
+            StringCollection.getSqlInString(userId, memberInGroups)).append("))) AND (changing_date > ?)").append(" AND (ot.module IN ").append(
             StringCollection.getSqlInString(accessibleModules)).append(")").append(
             OXFolderProperties.isEnableDBGrouping() ? " GROUP BY ot.fuid" : STR_EMPTY).append(" ORDER by ot.fuid");
         Connection readCon = null;
@@ -1277,7 +1277,7 @@ public class OXFolderTools {
      * since a given date.
      */
     public static SearchIterator getModifiedFoldersSince(final Date since, final int userId, final int[] memberInGroups, final int[] accessibleModules, final boolean userFoldersOnly, final Context ctx) throws OXException, SearchIteratorException {
-        final StringBuilder condBuilder = new StringBuilder("AND (changing_date >= ?) AND (module IN ").append(
+        final StringBuilder condBuilder = new StringBuilder("AND (changing_date > ?) AND (module IN ").append(
             FolderObject.SQL_IN_STR_STANDARD_MODULES).append(')');
         if (userFoldersOnly) {
             condBuilder.append(" AND (ot.created_from = ").append(userId).append(") ");
@@ -1323,7 +1323,7 @@ public class OXFolderTools {
      */
     public static SearchIterator getAllModifiedFoldersSince(final Date since, final Context ctx) throws OXException, SearchIteratorException {
         final String sqlSelectStr = new StringBuilder(300).append(SQL_SELECT_FOLDERS_START).append(
-            "AND (changing_date >= ?) AND (module IN ").append(FolderObject.SQL_IN_STR_STANDARD_MODULES).append(") ").append(
+            "AND (changing_date > ?) AND (module IN ").append(FolderObject.SQL_IN_STR_STANDARD_MODULES).append(") ").append(
             OXFolderProperties.isEnableDBGrouping() ? "GROUP BY ot.fuid" : null).append(" ORDER by ot.fuid").toString();
         Connection readCon = null;
         PreparedStatement stmt = null;
